/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * Author: Siamak Haschemi
 * Contact: haschemi@informatik.hu-berlin.de
 */
package net.sourceforge.osgi.deployment.maven.container;

import net.sourceforge.osgi.deployment.maven.IResource;

/**
 * <p>
 * From the Deployment Admin Specification:
 * </p>
 * <p>
 * A Deployment Package consists of installable <i>resources</i>. Resources are described in the <i>Name sections</i> of the Manifest. They are stored in the
 * JAR file under a path. This path is called the <i>resource id</i>. Subsets of these resources are the bundles. Bundles are treated differently from the
 * other resources by the Deployment Admin service. Non-bundle resources are called <i>processed resources</i>.
 * </p>
 * 
 * @author Siamak Haschemi, haschemi@informatik.hu-berlin.de
 * 
 */
public class ProcessedResource implements IResource {
  private String m_processor;
  private String m_filePath;
  private String m_targetPath;

  /**
   * A constructor which initializes an instance of a {@link ProcessedResource}.
   */
  public ProcessedResource() {
    m_processor = null;
    m_filePath = null;
    m_targetPath = null;
  }

  /**
   * @return the file
   */
  public final String getFilePath() {
    return m_filePath;
  }

  /**
   * @param p_filePath
   *          the file to set
   */
  public final void setFilePath(final String p_filePath) {
    m_filePath = p_filePath;
  }

  /**
   * @return the targetPath
   */
  public final String getTargetPath() {
    return m_targetPath;
  }

  /**
   * @param p_targetPath
   *          the targetPath to set
   */
  public final void setTargetPath(final String p_targetPath) {
    m_targetPath = p_targetPath;
  }

  /**
   * @return the processor
   */
  public final String getProcessor() {
    return m_processor;
  }

  /**
   * @param p_processor
   *          the processor to set
   */
  public final void setProcessor(final String p_processor) {
    m_processor = p_processor;
  }

  /**
   * @return the path and the name of the resource
   * @see net.sourceforge.osgi.deployment.maven.IResource#getResourceId()
   */
  public final String getResourceId() {
    String resourceId = m_filePath;
    if (m_targetPath != null && m_targetPath.length() > 0) {
      resourceId = m_targetPath + "/" + resourceId;
    }
    return resourceId;
  }

}
